notifier

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 21, 2017 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package notifier implements a simple helper for displaying output to users.

Credits: this package has been inspired by https://github.com/Masterminds/glide/blob/master/msg/msg.go.

Index

Constants

This section is empty.

Variables

var Houston = newOrbitNotifier()

Houston is the OrbitNotifier instance used by the application.

Functions

func Error

func Error(err error)

Error logs error information using the Houston notifier.

func Info

func Info(notification string, args ...interface{})

Info logs information using the Houston notifier.

func Mute

func Mute()

Mute disables the notifications.

Types

type OrbitNotifier

type OrbitNotifier struct {
	sync.Mutex
	// contains filtered or unexported fields
}

OrbitNotifier provides the underlying implementation that displays output to users.

Jump to