Documentation
¶
Overview ¶
Package notifier implements a simple helper for displaying output to users.
Credits: this package has been inspired by https://github.com/Masterminds/glide/blob/master/msg/msg.go.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Houston = newOrbitNotifier()
Houston is the OrbitNotifier instance used by the application.
Functions ¶
Types ¶
type OrbitNotifier ¶
OrbitNotifier provides the underlying implementation that displays output to users.
Click to show internal directories.
Click to hide internal directories.